@@ -11,14 +11,14 @@
 #include "eventview_p.h"
 #include "prefs.h"
 
-#include <EntityTreeModel>
+#include <Akonadi/EntityTreeModel>
 
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
-#include <ETMViewStateSaver>
-#include <EntityDisplayAttribute>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityDisplayAttribute>
 
 #include <KCalendarCore/CalFilter>
 
@@ -68,10 +68,7 @@ EventView::EventView(QWidget *parent)
     d_ptr->setUpModels();
 }
 
-EventView::~EventView()
-{
-    delete d_ptr;
-}
+EventView::~EventView() = default;
 
 void EventView::defaultAction(const Akonadi::Item &aitem)
 {
